@@ -1,4 +1,4 @@
-VERSION="1.10"
+VERSION="1.21"
 PACKAGE="blueman"
 WEBSITE="http://blueman-project.org"
 PREFIX="/usr"
@@ -7,14 +7,18 @@ ICON_PATH = "/usr/share/blueman/icons"
 UI_PATH = "/usr/share/blueman/ui"
 OBEX_BROWSE_AVAILABLE = True
 DHCP_CONFIG_FILE = "/etc/dhcp3/dhcpd.conf"
+POLKIT = "yes" == "yes"
+HAL_ENABLED = "no" == "yes"
 
 DEF_BROWSE_COMMAND = "nautilus --browser obex://[%d]"
 
 import os
 import gettext
+import __builtin__
 
-gettext.bindtextdomain("blueman", "/usr/share/locale")
-gettext.textdomain("blueman")
+translation = gettext.translation("blueman", "/usr/share/locale", fallback=True)
+translation.install(unicode=True)
+__builtin__.ngettext = translation.ungettext
 
 if os.path.exists("../apps") and os.path.exists("../data"):
 	BIN_DIR = "./"
